@@ -14,5 +14,9 @@ class InvalidHost(AidotError):
 class AidotAuthTokenExpired(AidotError):
     """Authentication failed because token is invalid or expired."""
 
-class AidotAuthVerificationCode(AidotError):
+class AidotAuthFailed(AidotError):
     """Authentication failed because MFA verification code is required."""
+
+class AidotUserOrPassIncorrect(AidotError):
+    """The password or email address is incorrect."""
+    
\ No newline at end of file
